@@ -42,10 +42,9 @@ def cleanup():
 		p = path.Path(filename)
 		if p.exists(): p.delete()
 
-
 def new_temppath():
 	"""Return a new TempPath"""
-	filename = tempfile.mktemp()
+	filename = tempfile.mktemp("","duplicity.")
 	register_filename(filename)
 	return TempPath(filename)
 
@@ -62,7 +61,6 @@ class TempPath(path.Path):
 		fh.addhook(self.delete)
 		return fh
 
-
 def get_fileobj_duppath(dirpath, filename):
 	"""Return a file object open for writing, will write to filename
 
@@ -81,7 +79,7 @@ def get_fileobj_duppath(dirpath, filename):
 
 def new_tempduppath(parseresults):
 	"""Return a new TempDupPath, using settings from parseresults"""
-	filename = tempfile.mktemp()
+	filename = tempfile.mktemp("","duplicity.")
 	register_filename(filename)
 	return TempDupPath(filename, parseresults = parseresults)
 
@@ -124,8 +122,8 @@ class FileobjHooked:
 	def close(self):
 		"""Close fileobj, running hooks right afterwards"""
 		assert not self.fileobj.close()
-		for hook in self.hooklist: hook()
 		if self.second: assert not self.second.close()
+		for hook in self.hooklist: hook()
 
 	def addhook(self, hook):
 		"""Add hook (function taking no arguments) to run upon closing"""
